align_of

Function align_of 

pub const fn align_of<T>() -> usize
🔬This is a nightly-only experimental API. (core_intrinsics)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
The minimum alignment of a type.

Note that, unlike most intrinsics, this is safe to call; it does not require an unsafe block. Therefore, implementations must not require the user to uphold any safety invariants.

Note that, unlike most intrinsics, this can only be called at compile-time as backends do not have an implementation for it. The only caller (its stable counterpart) wraps this intrinsic call in a const block so that backends only see an evaluated constant.

The stabilized version of this intrinsic is core::mem::align_of.