pub const fn assert_inhabited<T>()🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
A guard for unsafe functions that cannot ever be executed if T is uninhabited:
This will statically either panic, or do nothing. It does not guarantee to ever panic,
and should only be called if an assertion failure will imply language UB in the following code.
This intrinsic does not have a stable counterpart.