pub unsafe fn atomic_cxchg<T: Copy, const ORD_SUCC: AtomicOrdering, const ORD_FAIL: AtomicOrdering>(
dst: *mut T,
old: T,
src: T,
) -> (T, bool)🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Stores a value if the current value is the same as the old value.
T must be an integer or pointer type.
The stabilized version of this intrinsic is available on the
atomic types via the compare_exchange method.
For example, AtomicBool::compare_exchange.