pub const fn forget<T: ?Sized>(_: T)🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Moves a value out of scope without running drop glue.
This exists solely for crate::mem::forget_unsized; normal forget uses
ManuallyDrop instead.
Note that, unlike most intrinsics, this is safe to call;
it does not require an unsafe block.
Therefore, implementations must not require the user to uphold
any safety invariants.