unchecked_rem

Function unchecked_rem 

pub const unsafe fn unchecked_rem<T: Copy>(x: T, y: T) -> T
🔬This is a nightly-only experimental API. (core_intrinsics)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Returns the remainder of an unchecked division, resulting in undefined behavior when y == 0 or x == T::MIN && y == -1

Safe wrappers for this intrinsic are available on the integer primitives via the checked_rem method. For example, u32::checked_rem