pub fn abort() -> !🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Aborts the execution of the process.
Note that, unlike most intrinsics, this is safe to call;
it does not require an unsafe block.
Therefore, implementations must not require the user to uphold
any safety invariants.
std::process::abort is to be preferred if possible,
as its behavior is more user-friendly and more stable.
The current implementation of intrinsics::abort is to invoke an invalid instruction,
on most platforms.
On Unix, the
process will probably terminate with a signal like SIGABRT, SIGILL, SIGTRAP, SIGSEGV or
SIGBUS. The precise behavior is not guaranteed and not stable.