pub const fn cold_path()🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Hints to the compiler that current code path is cold.
Note that, unlike most intrinsics, this is safe to call;
it does not require an unsafe block.
Therefore, implementations must not require the user to uphold
any safety invariants.
The stabilized version of this intrinsic is core::hint::cold_path.