pub const unsafe fn unreachable() -> !🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Informs the optimizer that this point in the code is not reachable, enabling further optimizations.
N.B., this is very different from the unreachable!() macro: Unlike the
macro, which panics when it is executed, it is undefined behavior to
reach code marked with this function.
The stabilized version of this intrinsic is core::hint::unreachable_unchecked.